<script lang="ts">
  // The script block contains your component logic in TypeScript
</script>

<div class="{{ MOD.NAME }}">
  <!-- The div block defines your component's HTML structure -->
</div>

<style lang="css">
  @import './{{ MOD.NAME}} .css';
</style>