version: v2
meta:
  name: {{ spec_name }}
  description: "Design of Experiments for {{ spec_name }}"
  seed: 1
baseArtifact: base.yaml
factors:
  - name: model
    levels:
      - id: gpt-4o-mini
        patchRef: patches/model_gpt-4o-mini.yaml
        output_path: artifact.yaml
        patchKind: json-merge
      - id: gpt-4o-max
        patchRef: patches/model_gpt-4o-max.yaml
        output_path: artifact.yaml
        patchKind: json-merge
  - name: dataset
    levels:
      - id: news
        patchRef: patches/dataset_news.yaml
        output_path: artifact.yaml
        patchKind: json-merge
      - id: tweets
        patchRef: patches/dataset_tweets.yaml
        output_path: artifact.yaml
        patchKind: json-merge
factorSets:
  - name: grid
    cartesianProduct:
      model: [gpt-4o-mini, gpt-4o-max]
      dataset: [news, tweets]
    uriTemplate: "{model}-{dataset}"
