<template>
  <!-- The template block defines your component's HTML structure -->
</template>

<script lang="ts">
  // The script block contains your component logic in TypeScript
</script>

<style scoped src="{{ MOD.NAME }}">
  /* The style block imports CSS scoped to this component from the specified file */
</style>