"""Default evaluator pool used by :command:`peagen eval`."""

from __future__ import annotations

from swarmauri_standard.evaluator_pools.EvaluatorPool import (
    EvaluatorPool as DefaultEvaluatorPool,
)

__all__ = ["DefaultEvaluatorPool"]
