# Metadata for the DOE-spec '{{ org }}/{{ spec_name }}/{{ version }}'
# Generated by `peagen init doe-spec`.

name:        {{ spec_name }}
org:         {{ org }}
version:     {{ version }}           # bump when factors change
description: "Design of Experiments for {{ spec_name }}"

# SHA-256 checksum of doe_spec.yml; filled in by init_doe_spec().
checksum:    "{{ checksum }}"
